@@ -6,7 +6,7 @@ from netaddr import EUI
 from netaddr.core import AddrFormatError
 
 from netfields.compat import DatabaseWrapper, with_metaclass, text_type
-from netfields.forms import InetAddressFormField, CidrAddressFormField, MACAddressFormField
+from netfields.forms import InetAddressFormField, NoPrefixInetAddressFormField, CidrAddressFormField, MACAddressFormField
 from netfields.mac import mac_unix_common
 from netfields.psycopg2_types import Inet, Macaddr
 
@@ -146,7 +146,9 @@ class InetAddressField(_NetAddressField):
         return value
 
     def form_class(self):
-        return InetAddressFormField
+        if self.store_prefix_length:
+            return InetAddressFormField
+        return NoPrefixInetAddressFormField
 
 
 class CidrAddressField(_NetAddressField):
